@@ -4,12 +4,7 @@ from jinja2 import Environment, ChoiceLoader, PackageLoader, FileSystemLoader
 
 
 jade_config = DotDict({
-  'loaders': [
-    PackageLoader('frame', 'templates')
-  ],
-  'extensions': [],
-  'suffix': '.jade',
-  'directory': 'templates'
+  'environment': None
 })
 
 
@@ -17,12 +12,15 @@ class JadeDriver(Jinja2Driver):
   def __init__(self, **options):
     TemplateDriver.__init__(self, **options)
 
-    loaders = list(jade_config.loaders + options['loaders'])
-    loaders.insert(0, FileSystemLoader(jade_config.directory))
+    loaders = list(options['loaders'])
+    loaders.insert(0, FileSystemLoader(options['directory']))
 
-    self.environment = Environment(
-      loader=ChoiceLoader(loaders),
-      extensions=jade_config.extensions + ['pyjade.ext.jinja.PyJadeExtension'])
+    if jade_config.environment:
+      self.environment = jade_config.environment
+    else:
+      self.environment = Environment(
+        loader=ChoiceLoader(loaders),
+        extensions=options['extensions'] + ['pyjade.ext.jinja.PyJadeExtension'])
 
 
 def register_config(config):
@@ -30,4 +28,4 @@ def register_config(config):
 
 
 def register_driver(drivers):
-  drivers.register('template', 'jade', JadeDriver)
+  drivers.register('template', 'jade', JadeDriver)
\ No newline at end of file
